<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>GeoServiceProviderFactoryEsri</name>
    <message>
        <source>Esri plugin requires a &apos;esri.token&apos; parameter.
Please visit https://developers.arcgis.com/authentication/accessing-arcgis-online-services/</source>
        <translation>Das Esri-Plugin erfordert einen &apos;esri.token&apos; Parameter.
Bitte besuchen Sie https://developers.arcgis.com/authentication/accessing-arcgis-online-services/</translation>
    </message>
</context>
<context>
    <name>PlaceSearchReplyEsri</name>
    <message>
        <source>Response parse error</source>
        <translation>Fehler beim Auswerten der Antwort</translation>
    </message>
</context>
<context>
    <name>QDeclarativeGeoMap</name>
    <message>
        <source>No Map</source>
        <translation>Keine Karte</translation>
    </message>
    <message>
        <source>Plugin does not support mapping.</source>
        <translation>Das Plugin unterstützt keine Karten.</translation>
    </message>
</context>
<context>
    <name>QDeclarativeGeoRouteModel</name>
    <message>
        <source>Plugin does not support routing.</source>
        <translation>Das Plugin unterstützt keine Navigation.</translation>
    </message>
    <message>
        <source>Cannot route, plugin not set.</source>
        <translation>Kein Plugin gesetzt, kann keine Navigation durchführen.</translation>
    </message>
    <message>
        <source>Cannot route, route manager not set.</source>
        <translation>Es ist kein Routen-Manager gesetzt, kann keine Navigation durchführen.</translation>
    </message>
    <message>
        <source>Cannot route, valid query not set.</source>
        <translation>Es ist keine gültige Abfrage gesetzt, kann keine Navigation durchführen.</translation>
    </message>
    <message>
        <source>Not enough waypoints for routing.</source>
        <translation>Es sind nicht ausreichend Wegpunkte für die Navigation vorhanden.</translation>
    </message>
</context>
<context>
    <name>QDeclarativeGeocodeModel</name>
    <message>
        <source>Cannot geocode, plugin not set.</source>
        <translation>Kein Plugin gesetzt, kann keine Koordinatenbestimmung durchführen.</translation>
    </message>
    <message>
        <source>Cannot geocode, geocode manager not set.</source>
        <translation>Es ist kein Geocode-Manager gesetzt, kann keine Koordinatenbestimmung durchführen.</translation>
    </message>
    <message>
        <source>Cannot geocode, valid query not set.</source>
        <translation>Es ist keine gültige Abfrage gesetzt, kann keine Koordinatenbestimmung durchführen.</translation>
    </message>
    <message>
        <source>Plugin does not support (reverse) geocoding.</source>
        <translation>Das Plugin unterstützt keine (umgekehrte) Koordinatenbestimmung.</translation>
    </message>
</context>
<context>
    <name>QGeoCodeReplyMapbox</name>
    <message>
        <source>Response parse error</source>
        <translation>Fehler beim Auswerten der Antwort</translation>
    </message>
</context>
<context>
    <name>QGeoMapMapboxGL</name>
    <message>
        <source>Development access token, do not use in production.</source>
        <translation>Dieses Access-Token ist nur zur Entwicklung vorgesehen; es darf nicht in der Produktion verwendet werden.</translation>
    </message>
</context>
<context>
    <name>QGeoMappingManagerEngineItemsOverlay</name>
    <message>
        <source>Empty Map</source>
        <translation>Leere Karte</translation>
    </message>
</context>
<context>
    <name>QGeoMappingManagerEngineMapboxGL</name>
    <message>
        <source>China Streets</source>
        <translation>Straßen (chinesisch)</translation>
    </message>
    <message>
        <source>China Light</source>
        <translation>Hell (chinesisch)</translation>
    </message>
    <message>
        <source>China Dark</source>
        <translation>Dunkel (chinesisch)</translation>
    </message>
    <message>
        <source>Streets</source>
        <translation>Straßen</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Einfach</translation>
    </message>
    <message>
        <source>Bright</source>
        <translation>Hell</translation>
    </message>
    <message>
        <source>Outdoors</source>
        <translation>Outdoor-Karte</translation>
    </message>
    <message>
        <source>Satellite</source>
        <translation>Satellitenansicht</translation>
    </message>
    <message>
        <source>Satellite Streets</source>
        <translation>Straßenkarte in Satellitenansicht</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Hell</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Dunkel</translation>
    </message>
    <message>
        <source>Navigation Preview Day</source>
        <translation>Navigationsvorschau Tag</translation>
    </message>
    <message>
        <source>Navigation Preview Night</source>
        <translation>Navigationsvorschau Nacht</translation>
    </message>
    <message>
        <source>Navigation Guidance Day</source>
        <translation>Navigationsanleitung Tag</translation>
    </message>
    <message>
        <source>Navigation Guidance Night</source>
        <translation>Navigationsanleitung Nacht</translation>
    </message>
    <message>
        <source>User provided style</source>
        <translation>Benutzerdefinierter Stil</translation>
    </message>
</context>
<context>
    <name>QGeoRouteParserOsrmV4</name>
    <message>
        <source>Go straight.</source>
        <translation>Geradeaus folgen.</translation>
    </message>
    <message>
        <source>Go straight onto %1.</source>
        <translation>Fahren Sie geradeaus auf %1.</translation>
    </message>
    <message>
        <source>Turn slightly right.</source>
        <translation>Biegen Sie halbrechts ab.</translation>
    </message>
    <message>
        <source>Turn slightly right onto %1.</source>
        <translation>Biegen Sie halbrechts auf %1 ab.</translation>
    </message>
    <message>
        <source>Turn right.</source>
        <translation>Biegen Sie rechts ab.</translation>
    </message>
    <message>
        <source>Turn right onto %1.</source>
        <translation>Biegen Sie rechts auf %1 ab.</translation>
    </message>
    <message>
        <source>Make a sharp right.</source>
        <translation>Biegen Sie scharf rechts ab.</translation>
    </message>
    <message>
        <source>Make a sharp right onto %1.</source>
        <translation>Biegen Sie scharf rechts auf %1 ab.</translation>
    </message>
    <message>
        <source>When it is safe to do so, perform a U-turn.</source>
        <translation>Wenden Sie, sobald dies möglich ist.</translation>
    </message>
    <message>
        <source>Make a sharp left.</source>
        <translation>Biegen Sie scharf links ab.</translation>
    </message>
    <message>
        <source>Make a sharp left onto %1.</source>
        <translation>Biegen Sie scharf links auf %1 ab.</translation>
    </message>
    <message>
        <source>Turn left.</source>
        <translation>Biegen Sie links ab.</translation>
    </message>
    <message>
        <source>Turn left onto %1.</source>
        <translation>Biegen Sie links auf %1 ab.</translation>
    </message>
    <message>
        <source>Turn slightly left.</source>
        <translation>Biegen Sie halblinks ab.</translation>
    </message>
    <message>
        <source>Turn slightly left onto %1.</source>
        <translation>Biegen Sie halblinks auf %1 ab.</translation>
    </message>
    <message>
        <source>Reached waypoint.</source>
        <translation>Wegpunkt erreicht.</translation>
    </message>
    <message>
        <source>Head on.</source>
        <translation>Folgen Sie der Straße.</translation>
    </message>
    <message>
        <source>Head onto %1.</source>
        <translation>Weiter auf %1.</translation>
    </message>
    <message>
        <source>Enter the roundabout.</source>
        <translation>In den Kreisverkehr einfahren.</translation>
    </message>
    <message>
        <source>At the roundabout take the first exit.</source>
        <translation>Nehmen Sie die erste Ausfahrt aus dem Kreisverkehr.</translation>
    </message>
    <message>
        <source>At the roundabout take the first exit onto %1.</source>
        <translation>Nehmen Sie die erste Ausfahrt aus dem Kreisverkehr, um auf %1 zu wechseln.</translation>
    </message>
    <message>
        <source>At the roundabout take the second exit.</source>
        <translation>Nehmen Sie die zweite Ausfahrt aus dem Kreisverkehr.</translation>
    </message>
    <message>
        <source>At the roundabout take the second exit onto %1.</source>
        <translation>Nehmen Sie die zweite Ausfahrt aus dem Kreisverkehr, um auf %1 zu wechseln.</translation>
    </message>
    <message>
        <source>At the roundabout take the third exit.</source>
        <translation>Nehmen Sie die dritte Ausfahrt aus dem Kreisverkehr.</translation>
    </message>
    <message>
        <source>At the roundabout take the third exit onto %1.</source>
        <translation>Nehmen Sie die dritte Ausfahrt aus dem Kreisverkehr, um auf %1 zu wechseln.</translation>
    </message>
    <message>
        <source>At the roundabout take the fourth exit.</source>
        <translation>Nehmen Sie die vierte Ausfahrt aus dem Kreisverkehr.</translation>
    </message>
    <message>
        <source>At the roundabout take the fourth exit onto %1.</source>
        <translation>Nehmen Sie die vierte Ausfahrt aus dem Kreisverkehr, um auf %1 zu wechseln.</translation>
    </message>
    <message>
        <source>At the roundabout take the fifth exit.</source>
        <translation>Nehmen Sie die fünfte Ausfahrt aus dem Kreisverkehr.</translation>
    </message>
    <message>
        <source>At the roundabout take the fifth exit onto %1.</source>
        <translation>Nehmen Sie die fünfte Ausfahrt aus dem Kreisverkehr, um auf %1 zu wechseln.</translation>
    </message>
    <message>
        <source>At the roundabout take the sixth exit.</source>
        <translation>Nehmen Sie die sechste Ausfahrt aus dem Kreisverkehr.</translation>
    </message>
    <message>
        <source>At the roundabout take the sixth exit onto %1.</source>
        <translation>Nehmen Sie die sechste Ausfahrt aus dem Kreisverkehr, um auf %1 zu wechseln.</translation>
    </message>
    <message>
        <source>At the roundabout take the seventh exit.</source>
        <translation>Nehmen Sie die siebte Ausfahrt aus dem Kreisverkehr.</translation>
    </message>
    <message>
        <source>At the roundabout take the seventh exit onto %1.</source>
        <translation>Nehmen Sie die siebte Ausfahrt aus dem Kreisverkehr, um auf %1 zu wechseln.</translation>
    </message>
    <message>
        <source>At the roundabout take the eighth exit.</source>
        <translation>Nehmen Sie die achte Ausfahrt aus dem Kreisverkehr.</translation>
    </message>
    <message>
        <source>At the roundabout take the eighth exit onto %1.</source>
        <translation>Nehmen Sie die achte Ausfahrt aus dem Kreisverkehr, um auf %1 zu wechseln.</translation>
    </message>
    <message>
        <source>At the roundabout take the ninth exit.</source>
        <translation>Nehmen Sie die neunte Ausfahrt aus dem Kreisverkehr.</translation>
    </message>
    <message>
        <source>At the roundabout take the ninth exit onto %1.</source>
        <translation>Nehmen Sie die neunte Ausfahrt aus dem Kreisverkehr, um auf %1 zu wechseln.</translation>
    </message>
    <message>
        <source>Leave the roundabout.</source>
        <translation>Verlassen Sie den Kreisverkehr.</translation>
    </message>
    <message>
        <source>Leave the roundabout onto %1.</source>
        <translation>Verlassen Sie den Kreisverkehr, um auf %1 zu wechseln.</translation>
    </message>
    <message>
        <source>Stay on the roundabout.</source>
        <translation>Folgen Sie dem Kreisverkehr.</translation>
    </message>
    <message>
        <source>Start at the end of the street.</source>
        <translation>Starten Sie am Ende der Straße.</translation>
    </message>
    <message>
        <source>Start at the end of %1.</source>
        <translation>Starten Sie am Ende von %1.</translation>
    </message>
    <message>
        <source>You have reached your destination.</source>
        <translation>Sie haben Ihr Ziel erreicht.</translation>
    </message>
    <message>
        <source>Don&apos;t know what to say for &apos;%1&apos;</source>
        <translation>Unbekannte Anweisung: %1</translation>
    </message>
</context>
<context>
    <name>QGeoRouteParserOsrmV5</name>
    <message>
        <source>North</source>
        <extracomment>Translations exist at https://github.com/Project-OSRM/osrm-text-instructions. Always used in &quot;Head %1 [onto &lt;street name&gt;]&quot;</extracomment>
        <translation>nach Norden</translation>
    </message>
    <message>
        <source>East</source>
        <translation>nach Osten</translation>
    </message>
    <message>
        <source>South</source>
        <translation>nach Süden </translation>
    </message>
    <message>
        <source>West</source>
        <translation>nach Westen</translation>
    </message>
    <message>
        <source>first</source>
        <comment>roundabout exit</comment>
        <extracomment>always used in &quot; and take the %1 exit [onto &lt;street name&gt;]&quot;</extracomment>
        <translation>erste</translation>
    </message>
    <message>
        <source>second</source>
        <comment>roundabout exit</comment>
        <translation>zweite</translation>
    </message>
    <message>
        <source>third</source>
        <comment>roundabout exit</comment>
        <translation>dritte</translation>
    </message>
    <message>
        <source>fourth</source>
        <comment>roundabout exit</comment>
        <translation>vierte</translation>
    </message>
    <message>
        <source>fifth</source>
        <comment>roundabout exit</comment>
        <translation>fünfte</translation>
    </message>
    <message>
        <source>sixth</source>
        <comment>roundabout exit</comment>
        <translation>sechste</translation>
    </message>
    <message>
        <source>seventh</source>
        <comment>roundabout exit</comment>
        <translation>siebente</translation>
    </message>
    <message>
        <source>eighth</source>
        <comment>roundabout exit</comment>
        <translation>achte</translation>
    </message>
    <message>
        <source>ninth</source>
        <comment>roundabout exit</comment>
        <translation>neunte</translation>
    </message>
    <message>
        <source>tenth</source>
        <comment>roundabout exit</comment>
        <translation>zehnte</translation>
    </message>
    <message>
        <source>eleventh</source>
        <comment>roundabout exit</comment>
        <translation>elfte</translation>
    </message>
    <message>
        <source>twelfth</source>
        <comment>roundabout exit</comment>
        <translation>zwölfte</translation>
    </message>
    <message>
        <source>thirteenth</source>
        <comment>roundabout exit</comment>
        <translation>dreizehnte</translation>
    </message>
    <message>
        <source>fourteenth</source>
        <comment>roundabout exit</comment>
        <translation>vierzehnte</translation>
    </message>
    <message>
        <source>fifteenth</source>
        <comment>roundabout exit</comment>
        <translation>fünfzehnte</translation>
    </message>
    <message>
        <source>sixteenth</source>
        <comment>roundabout exit</comment>
        <translation>sechzehnte</translation>
    </message>
    <message>
        <source>seventeenth</source>
        <comment>roundabout exit</comment>
        <translation>siebzehnte</translation>
    </message>
    <message>
        <source>eighteenth</source>
        <comment>roundabout exit</comment>
        <translation>achtzehnte</translation>
    </message>
    <message>
        <source>nineteenth</source>
        <comment>roundabout exit</comment>
        <translation>neunzehnte</translation>
    </message>
    <message>
        <source>twentieth</source>
        <comment>roundabout exit</comment>
        <translation>zwanzigste</translation>
    </message>
    <message>
        <source> and take the %1 exit</source>
        <extracomment>Always appended to one of the following strings: - &quot;Enter the roundabout&quot; - &quot;Enter the rotary&quot; - &quot;Enter the rotary &lt;rotaryname&gt;&quot;</extracomment>
        <translation> und nehmen Sie die %1 Ausfahrt</translation>
    </message>
    <message>
        <source> and take the %1 exit onto %2</source>
        <translation> und nehmen Sie die %1 Ausfahrt auf %2</translation>
    </message>
    <message>
        <source>You have arrived at your destination, straight ahead</source>
        <translation>Ihr Ziel liegt geradeaus vor Ihnen</translation>
    </message>
    <message>
        <source>You have arrived at your destination, on the left</source>
        <translation>Ihr Ziel liegt links vor Ihnen</translation>
    </message>
    <message>
        <source>You have arrived at your destination, on the right</source>
        <translation>Ihr Ziel liegt rechts vor Ihnen</translation>
    </message>
    <message>
        <source>You have arrived at your destination</source>
        <translation>Sie haben Ihr Ziel erreicht</translation>
    </message>
    <message>
        <source>Continue straight</source>
        <translation>Fahren Sie geradeaus weiter</translation>
    </message>
    <message>
        <source>Continue straight on %1</source>
        <translation>Fahren Sie geradeaus auf %1 weiter</translation>
    </message>
    <message>
        <source>Continue left</source>
        <translation>Fahren Sie links weiter</translation>
    </message>
    <message>
        <source>Continue left onto %1</source>
        <translation>Fahren Sie links auf %1 weiter</translation>
    </message>
    <message>
        <source>Continue slightly left</source>
        <translation>Fahren Sie halblinks weiter</translation>
    </message>
    <message>
        <source>Continue slightly left on %1</source>
        <translation>Fahren Sie halblinks auf %1 weiter</translation>
    </message>
    <message>
        <source>Continue right</source>
        <translation>Fahren Sie rechts weiter</translation>
    </message>
    <message>
        <source>Continue right onto %1</source>
        <translation>Fahren Sie rechts auf %1 weiter</translation>
    </message>
    <message>
        <source>Continue slightly right</source>
        <translation>Fahren Sie halbrechts weiter</translation>
    </message>
    <message>
        <source>Continue slightly right on %1</source>
        <translation>Fahren Sie halbrechts auf %1 weiter</translation>
    </message>
    <message>
        <source>Make a U-turn</source>
        <translation>Bitte wenden Sie</translation>
    </message>
    <message>
        <source>Make a U-turn onto %1</source>
        <translation>Bitte wenden Sie auf %1</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Fahren Sie weiter</translation>
    </message>
    <message>
        <source>Continue on %1</source>
        <translation>Fahren Sie auf %1 weiter</translation>
    </message>
    <message>
        <source>Head %1</source>
        <extracomment>%1 is &quot;North&quot;, &quot;South&quot;, &quot;East&quot; or &quot;West&quot;</extracomment>
        <translation>Fahren Sie %1</translation>
    </message>
    <message>
        <source>Head %1 onto %2</source>
        <translation>Fahren Sie %1 auf %2</translation>
    </message>
    <message>
        <source>Depart</source>
        <translation>Fahren Sie ab</translation>
    </message>
    <message>
        <source>Depart onto %1</source>
        <translation>Fahren Sie auf %1 ab</translation>
    </message>
    <message>
        <source>At the end of the road, turn left</source>
        <translation>Biegen Sie am Ende der Straße links ab</translation>
    </message>
    <message>
        <source>At the end of the road, turn left onto %1</source>
        <translation>Biegen Sie am Ende der Straße links auf %1 ab</translation>
    </message>
    <message>
        <source>At the end of the road, turn right</source>
        <translation>Biegen Sie am Ende der Straße rechts ab</translation>
    </message>
    <message>
        <source>At the end of the road, turn right onto %1</source>
        <translation>Biegen Sie am Ende der Straße rechts auf %1 ab</translation>
    </message>
    <message>
        <source>At the end of the road, make a U-turn</source>
        <translation>Wenden Sie am Ende der Straße</translation>
    </message>
    <message>
        <source>At the end of the road, make a U-turn onto %1</source>
        <translation>Wenden Sie am Ende der Straße auf %1</translation>
    </message>
    <message>
        <source>At the end of the road, continue straight</source>
        <translation>Fahren Sie am Ende der Straße geradeaus weiter</translation>
    </message>
    <message>
        <source>At the end of the road, continue straight onto %1</source>
        <translation>Fahren Sie am Ende der Straße geradeaus auf %1 weiter</translation>
    </message>
    <message>
        <source>At the end of the road, continue</source>
        <translation>Fahren Sie am Ende der Straße weiter</translation>
    </message>
    <message>
        <source>At the end of the road, continue onto %1</source>
        <translation>Fahren Sie am Ende der Straße auf %1 weiter</translation>
    </message>
    <message>
        <source>Take the ferry</source>
        <translation>Nehmen Sie die Fähre</translation>
    </message>
    <message>
        <source>At the fork, take a sharp left</source>
        <translation>Biegen Sie an der Gabelung scharf links ab</translation>
    </message>
    <message>
        <source>At the fork, take a sharp left onto %1</source>
        <translation>Biegen Sie an der Gabelung scharf links auf %1 ab</translation>
    </message>
    <message>
        <source>At the fork, turn left</source>
        <translation>Biegen Sie an der Gabelung links ab</translation>
    </message>
    <message>
        <source>At the fork, turn left onto %1</source>
        <translation>Biegen Sie an der Gabelung links auf %1 ab</translation>
    </message>
    <message>
        <source>At the fork, keep left</source>
        <translation>Halten Sie sich an der Gabelung links</translation>
    </message>
    <message>
        <source>At the fork, keep left onto %1</source>
        <translation>Halten Sie sich an der Gabelung links auf %1</translation>
    </message>
    <message>
        <source>At the fork, take a sharp right</source>
        <translation>Biegen Sie an der Gabelung scharf rechts ab</translation>
    </message>
    <message>
        <source>At the fork, take a sharp right onto %1</source>
        <translation>Biegen Sie an der Gabelung scharf rechts auf %1 ab</translation>
    </message>
    <message>
        <source>At the fork, turn right</source>
        <translation>Biegen Sie an der Gabelung rechts ab</translation>
    </message>
    <message>
        <source>At the fork, turn right onto %1</source>
        <translation>Biegen Sie an der Gabelung rechts auf %1 ab</translation>
    </message>
    <message>
        <source>At the fork, keep right</source>
        <translation>Halten Sie sich an der Gabelung rechts</translation>
    </message>
    <message>
        <source>At the fork, keep right onto %1</source>
        <translation>Halten Sie sich an der Gabelung rechts auf %1</translation>
    </message>
    <message>
        <source>At the fork, continue straight ahead</source>
        <translation>Fahren Sie an der Gabelung geradeaus weiter</translation>
    </message>
    <message>
        <source>At the fork, continue straight ahead onto %1</source>
        <translation>Fahren Sie an der Gabelung geradeaus auf %1 weiter</translation>
    </message>
    <message>
        <source>At the fork, continue</source>
        <translation>Fahren Sie an der Gabelung weiter</translation>
    </message>
    <message>
        <source>At the fork, continue onto %1</source>
        <translation>Fahren Sie an der Gabelung auf %1 weiter</translation>
    </message>
    <message>
        <source>Merge sharply left</source>
        <translation>Fahren Sie scharf links auf</translation>
    </message>
    <message>
        <source>Merge sharply left onto %1</source>
        <translation>Fahren Sie scharf links auf %1 auf</translation>
    </message>
    <message>
        <source>Merge left</source>
        <translation>Fahren Sie links auf</translation>
    </message>
    <message>
        <source>Merge left onto %1</source>
        <translation>Fahren Sie links auf %1 auf</translation>
    </message>
    <message>
        <source>Merge slightly left</source>
        <translation>Fahren Sie halblinks auf</translation>
    </message>
    <message>
        <source>Merge slightly left on %1</source>
        <translation>Fahren Sie halblinks auf %1 auf</translation>
    </message>
    <message>
        <source>Merge sharply right</source>
        <translation>Fahren Sie in scharf rechts auf</translation>
    </message>
    <message>
        <source>Merge sharply right onto %1</source>
        <translation>Fahren Sie scharf rechts auf %1 auf</translation>
    </message>
    <message>
        <source>Merge right</source>
        <translation>Fahren Sie rechts auf</translation>
    </message>
    <message>
        <source>Merge right onto %1</source>
        <translation>Fahren Sie rechts auf %1 auf</translation>
    </message>
    <message>
        <source>Merge slightly right</source>
        <translation>Fahren Sie halbrechts auf</translation>
    </message>
    <message>
        <source>Merge slightly right on %1</source>
        <translation>Fahren Sie halbrechts auf %1 auf</translation>
    </message>
    <message>
        <source>Merge straight</source>
        <translation>Fahren Sie geradeaus auf</translation>
    </message>
    <message>
        <source>Merge straight on %1</source>
        <translation>Fahren Sie geradeaus auf %1 auf</translation>
    </message>
    <message>
        <source>Merge</source>
        <translation>Fahren Sie auf</translation>
    </message>
    <message>
        <source>Merge onto %1</source>
        <translation>Fahren Sie auf %1 auf</translation>
    </message>
    <message>
        <source>Take a sharp left</source>
        <translation>Biegen Sie scharf links ab</translation>
    </message>
    <message>
        <source>Take a sharp left onto %1</source>
        <translation>Biegen Sie scharf links auf %1 ab</translation>
    </message>
    <message>
        <source>Turn left</source>
        <translation>Biegen Sie links ab</translation>
    </message>
    <message>
        <source>Turn left onto %1</source>
        <translation>Biegen Sie links auf %1 ab</translation>
    </message>
    <message>
        <source>Continue slightly left onto %1</source>
        <translation>Fahren Sie halblinks auf %1 weiter</translation>
    </message>
    <message>
        <source>Take a sharp right</source>
        <translation>Biegen Sie scharf rechts ab</translation>
    </message>
    <message>
        <source>Take a sharp right onto %1</source>
        <translation>Biegen Sie scharf rechts auf %1 ab</translation>
    </message>
    <message>
        <source>Turn right</source>
        <translation>Biegen Sie rechts ab</translation>
    </message>
    <message>
        <source>Turn right onto %1</source>
        <translation>Biegen Sie rechts auf %1 ab</translation>
    </message>
    <message>
        <source>Continue slightly right onto %1</source>
        <translation>Fahren Sie halbrechts auf %1 weiter</translation>
    </message>
    <message>
        <source>Continue straight onto %1</source>
        <translation>Fahren Sie geradeaus auf %1 weiter</translation>
    </message>
    <message>
        <source>Continue onto %1</source>
        <translation>Fahren Sie auf %1 weiter</translation>
    </message>
    <message>
        <source>Continue on the left</source>
        <translation>Fahren Sie links weiter</translation>
    </message>
    <message>
        <source>Continue on the left on %1</source>
        <translation>Fahren Sie links auf %1 weiter</translation>
    </message>
    <message>
        <source>Continue on the right</source>
        <translation>Fahren Sie rechts weiter</translation>
    </message>
    <message>
        <source>Continue on the right on %1</source>
        <translation>Fahren Sie rechts auf %1 weiter</translation>
    </message>
    <message>
        <source>Take the ramp on the left</source>
        <translation>Fahren Sie auf die linke Auffahrt</translation>
    </message>
    <message>
        <source>Take the ramp on the left onto %1</source>
        <translation>Fahren Sie über die linke Auffahrt auf %1</translation>
    </message>
    <message>
        <source>Take the ramp on the right</source>
        <translation>Fahren Sie auf die rechte Auffahrt</translation>
    </message>
    <message>
        <source>Take the ramp on the right onto %1</source>
        <translation>Fahren Sie über die rechte Auffahrt auf %1</translation>
    </message>
    <message>
        <source>Take the ramp</source>
        <translation>Fahren Sie auf die Auffahrt</translation>
    </message>
    <message>
        <source>Take the ramp onto %1</source>
        <translation>Fahren Sie über die Auffahrt auf %1</translation>
    </message>
    <message>
        <source>Get off the bike and push</source>
        <translation>Steigen Sie ab und schieben Sie das Fahrrad</translation>
    </message>
    <message>
        <source>Get off the bike and push onto %1</source>
        <translation>Steigen Sie ab und schieben Sie das Rad auf %1</translation>
    </message>
    <message>
        <source>Enter the rotary</source>
        <extracomment>This string will be prepended to &quot; and take the &lt;nth&gt; exit [onto &lt;streetname&gt;]</extracomment>
        <translation>Fahren Sie in den Kreisverkehr</translation>
    </message>
    <message>
        <source>Enter the roundabout</source>
        <extracomment>This string will be prepended to &quot; and take the &lt;nth&gt; exit [onto &lt;streetname&gt;]</extracomment>
        <translation>Fahren Sie in den Kreisverkehr ein</translation>
    </message>
    <message>
        <source>At the roundabout, continue straight</source>
        <translation>Fahren Sie im Kreisverkehr geradeaus weiter</translation>
    </message>
    <message>
        <source>At the roundabout, continue straight on %1</source>
        <translation>Fahren Sie im Kreisverkehr geradeaus auf %1 weiter</translation>
    </message>
    <message>
        <source>At the roundabout, turn left</source>
        <translation>Biegen Sie im Kreisverkehr links ab</translation>
    </message>
    <message>
        <source>At the roundabout, turn left onto %1</source>
        <translation>Biegen Sie im Kreisverkehr links auf %1 ab</translation>
    </message>
    <message>
        <source>At the roundabout, turn right</source>
        <translation>Biegen Sie im Kreisverkehr rechts ab</translation>
    </message>
    <message>
        <source>At the roundabout, turn right onto %1</source>
        <translation>Biegen Sie im Kreisverkehr rechts auf %1 ab</translation>
    </message>
    <message>
        <source>At the roundabout, turn around</source>
        <translation>Wenden Sie im Kreisverkehr</translation>
    </message>
    <message>
        <source>At the roundabout, turn around onto %1</source>
        <translation>Wenden Sie im Kreisverkehr auf %1</translation>
    </message>
    <message>
        <source>At the roundabout, continue</source>
        <translation>Fahren Sie durch den Kreisverkehr weiter</translation>
    </message>
    <message>
        <source>At the roundabout, continue onto %1</source>
        <translation>Fahren Sie im Kreisverkehr auf %1 weiter</translation>
    </message>
    <message>
        <source>Take the train</source>
        <translation>Nehmen Sie den Zug</translation>
    </message>
    <message>
        <source>Take the train [%1]</source>
        <translation>Nehmen Sie den Zug [%1]</translation>
    </message>
    <message>
        <source>Go straight</source>
        <translation>Fahren Sie geradeaus</translation>
    </message>
    <message>
        <source>Go straight onto %1</source>
        <translation>Fahren Sie geradeaus auf %1</translation>
    </message>
    <message>
        <source>Turn slightly left</source>
        <translation>Biegen Sie halblinks ab</translation>
    </message>
    <message>
        <source>Turn slightly left onto %1</source>
        <translation>Biegen Sie halblinks auf %1 ab</translation>
    </message>
    <message>
        <source>Turn slightly right</source>
        <translation>Biegen Sie halbrechts ab</translation>
    </message>
    <message>
        <source>Turn slightly right onto %1</source>
        <translation>Biegen Sie halbrechts auf %1 ab</translation>
    </message>
    <message>
        <source>Turn</source>
        <translation>Biegen Sie ab</translation>
    </message>
    <message>
        <source>Turn onto %1</source>
        <translation>Biegen Sie auf %1 ab</translation>
    </message>
    <message>
        <source> and continue straight</source>
        <extracomment>This string will be prepended with lane instructions. E.g., &quot;Use the left or the right lane and continue straight&quot;</extracomment>
        <translation> und fahren Sie geradeaus weiter</translation>
    </message>
    <message>
        <source> and continue straight onto %1</source>
        <translation> und fahren Sie geradeaus auf %1 weiter</translation>
    </message>
    <message>
        <source> and make a sharp left</source>
        <translation> und biegen Sie scharf links ab</translation>
    </message>
    <message>
        <source> and make a sharp left onto %1</source>
        <translation> und biegen Sie scharf links auf %1 ab</translation>
    </message>
    <message>
        <source> and turn left</source>
        <translation> und biegen Sie links ab</translation>
    </message>
    <message>
        <source> and turn left onto %1</source>
        <translation> und biegen Sie links auf %1 ab</translation>
    </message>
    <message>
        <source> and make a slight left</source>
        <translation> und biegen Sie halblinks ab</translation>
    </message>
    <message>
        <source> and make a slight left onto %1</source>
        <translation> und biegen Sie halblinls auf %1 ab</translation>
    </message>
    <message>
        <source> and make a sharp right</source>
        <translation> und biegen Sie scharf rechts ab</translation>
    </message>
    <message>
        <source> and make a sharp right onto %1</source>
        <translation> und biegen Sie scharf rechts auf %1 ab</translation>
    </message>
    <message>
        <source> and turn right</source>
        <translation> und biegen Sie rechts ab</translation>
    </message>
    <message>
        <source> and turn right onto %1</source>
        <translation> und biegen Sie rechts auf %1 ab</translation>
    </message>
    <message>
        <source> and make a slight right</source>
        <translation> und biegen Sie halbrechts ab</translation>
    </message>
    <message>
        <source> and make a slight right onto %1</source>
        <translation> und biegen Sie halbrechts auf %1 ab</translation>
    </message>
    <message>
        <source> and make a U-turn</source>
        <translation> und wenden Sie</translation>
    </message>
    <message>
        <source> and make a U-turn onto %1</source>
        <translation> und wenden Sie auf %1</translation>
    </message>
</context>
<context>
    <name>QGeoServiceProviderFactoryMapbox</name>
    <message>
        <source>Mapbox plugin requires a &apos;mapbox.access_token&apos; parameter.
Please visit https://www.mapbox.com</source>
        <translation>Das Mapbox-Plugin erfordert einen Parameter &apos;mapbox.access_token&apos;.
Bitte besuchen Sie https://www.mapbox.com</translation>
    </message>
</context>
<context>
    <name>QGeoTileFetcherNokia</name>
    <message>
        <source>Mapping manager no longer exists</source>
        <translation>Kartenmanager existiert nicht mehr</translation>
    </message>
</context>
<context>
    <name>QGeoTiledMappingManagerEngineMapbox</name>
    <message>
        <source>Street</source>
        <extracomment>Noun describing map type &apos;Street map&apos;</extracomment>
        <translation>Straßenkarte</translation>
    </message>
    <message>
        <source>Light</source>
        <extracomment>Noun describing type of a map using light colors (weak contrast)</extracomment>
        <translation>Hell</translation>
    </message>
    <message>
        <source>Dark</source>
        <extracomment>Noun describing type of a map using dark colors</extracomment>
        <translation>Dunkel</translation>
    </message>
    <message>
        <source>Satellite</source>
        <extracomment>Noun describing type of a map created by satellite</extracomment>
        <translation>Satellitenansicht</translation>
    </message>
    <message>
        <source>Streets Satellite</source>
        <extracomment>Noun describing type of a street map created by satellite</extracomment>
        <translation>Straßenkarte in Satellitenansicht</translation>
    </message>
    <message>
        <source>Wheatpaste</source>
        <extracomment>Noun describing type of a map using wheat paste colors</extracomment>
        <translation>mehlfarben</translation>
    </message>
    <message>
        <source>Streets Basic</source>
        <extracomment>Noun describing type of a basic street map</extracomment>
        <translation>Einfache Straßenkarte</translation>
    </message>
    <message>
        <source>Comic</source>
        <extracomment>Noun describing type of a map using cartoon-style fonts</extracomment>
        <translation>Comic</translation>
    </message>
    <message>
        <source>Outdoors</source>
        <extracomment>Noun describing type of a map for outdoor activities</extracomment>
        <translation>Outdoor-Karte</translation>
    </message>
    <message>
        <source>Run Bike Hike</source>
        <extracomment>Noun describing type of a map for sports</extracomment>
        <translation>Laufen Radfahren Wandern</translation>
    </message>
    <message>
        <source>Pencil</source>
        <extracomment>Noun describing type of a map drawn by pencil</extracomment>
        <translation>Bleistiftzeichnung</translation>
    </message>
    <message>
        <source>Pirates</source>
        <extracomment>Noun describing type of a treasure map with pirate boat watermark</extracomment>
        <translation>Schatzkarte</translation>
    </message>
    <message>
        <source>Emerald</source>
        <extracomment>Noun describing type of a map using emerald colors</extracomment>
        <translation>Smaragdfarben</translation>
    </message>
    <message>
        <source>High Contrast</source>
        <extracomment>Noun describing type of a map with high contrast</extracomment>
        <translation>Hoher Kontrast</translation>
    </message>
</context>
<context>
    <name>QGeoTiledMappingManagerEngineNokia</name>
    <message>
        <source>Street Map</source>
        <translation>Karte (Normal)</translation>
    </message>
    <message>
        <source>Normal map view in daylight mode</source>
        <translation>Karte bei Tageslicht</translation>
    </message>
    <message>
        <source>Satellite Map</source>
        <translation>Karte (Satellite)</translation>
    </message>
    <message>
        <source>Satellite map view in daylight mode</source>
        <translation>Satellitenkarte bei Tageslicht</translation>
    </message>
    <message>
        <source>Terrain Map</source>
        <translation>Karte (Topografie)</translation>
    </message>
    <message>
        <source>Terrain map view in daylight mode</source>
        <translation>Topografische Karte bei Tageslicht</translation>
    </message>
    <message>
        <source>Hybrid Map</source>
        <translation>Karte (Hybrid)</translation>
    </message>
    <message>
        <source>Satellite map view with streets in daylight mode</source>
        <translation>Satellitenkarte mit Straßen bei Tageslicht</translation>
    </message>
    <message>
        <source>Transit Map</source>
        <translation>Karte (Nahverkehr)</translation>
    </message>
    <message>
        <source>Color-reduced map view with public transport scheme in daylight mode</source>
        <translation>Farbreduzierte Karte mit öffentlichen Nahverkehr bei Tageslicht</translation>
    </message>
    <message>
        <source>Gray Street Map</source>
        <translation>Karte (Grau)</translation>
    </message>
    <message>
        <source>Color-reduced map view in daylight mode</source>
        <translation>Farbreduzierte Karte bei Tageslicht</translation>
    </message>
    <message>
        <source>Mobile Street Map</source>
        <translation>Karte (Mobil)</translation>
    </message>
    <message>
        <source>Mobile normal map view in daylight mode</source>
        <translation>Mobilkarte bei Tageslicht</translation>
    </message>
    <message>
        <source>Mobile Terrain Map</source>
        <translation>Karte (Mobil/Topografie)</translation>
    </message>
    <message>
        <source>Mobile terrain map view in daylight mode</source>
        <translation>Mobile topografische Karte bei Tageslicht</translation>
    </message>
    <message>
        <source>Mobile Hybrid Map</source>
        <translation>Karte (Mobil/Hybrid)</translation>
    </message>
    <message>
        <source>Mobile satellite map view with streets in daylight mode</source>
        <translation>Mobile Satellitenkarte mit Straßen bei Tageslicht</translation>
    </message>
    <message>
        <source>Mobile Transit Map</source>
        <translation>Karte (Mobil/Nahverkehr)</translation>
    </message>
    <message>
        <source>Mobile color-reduced map view with public transport scheme in daylight mode</source>
        <translation>Farbreduzierte Karte für mobile Nutzung mit öffentlichen Nahverkehr bei Tageslicht</translation>
    </message>
    <message>
        <source>Mobile Gray Street Map</source>
        <translation>Karte (Mobil/Grau)</translation>
    </message>
    <message>
        <source>Mobile color-reduced map view in daylight mode</source>
        <translation>Farbreduzierte Karte für mobile Nutzung bei Tageslicht</translation>
    </message>
    <message>
        <source>Custom Street Map</source>
        <translation>Karte (Angepasst)</translation>
    </message>
    <message>
        <source>Night Street Map</source>
        <translation>Karte (Nacht)</translation>
    </message>
    <message>
        <source>Normal map view in night mode</source>
        <translation>Karte bei Nacht</translation>
    </message>
    <message>
        <source>Mobile Night Street Map</source>
        <translation>Karte (Mobil/Nacht)</translation>
    </message>
    <message>
        <source>Mobile normal map view in night mode</source>
        <translation>Mobilkarte bei Nacht</translation>
    </message>
    <message>
        <source>Gray Night Street Map</source>
        <translation>Karte (Nacht/Grau)</translation>
    </message>
    <message>
        <source>Color-reduced map view in night mode (especially used for background maps)</source>
        <translation>Farbreduzierte Karte bei Nacht</translation>
    </message>
    <message>
        <source>Mobile Gray Night Street Map</source>
        <translation>Karte (Mobil/Grau/Nacht)</translation>
    </message>
    <message>
        <source>Mobile color-reduced map view in night mode (especially used for background maps)</source>
        <translation>Farbreduzierte Karte für mobile Nutzung bei Nacht</translation>
    </message>
    <message>
        <source>Pedestrian Street Map</source>
        <translation>Fußgängerkarte</translation>
    </message>
    <message>
        <source>Pedestrian map view in daylight mode</source>
        <translation>Fußgängerkarte bei Tageslicht</translation>
    </message>
    <message>
        <source>Mobile Pedestrian Street Map</source>
        <translation>Mobile Fußgängerkarte</translation>
    </message>
    <message>
        <source>Mobile pedestrian map view in daylight mode for mobile usage</source>
        <translation>Fußgängerkarte für mobilen Einsatz bei Tageslicht</translation>
    </message>
    <message>
        <source>Pedestrian map view in night mode</source>
        <translation>Fußgängerkarte bei Nacht</translation>
    </message>
    <message>
        <source>Mobile Pedestrian Night Street Map</source>
        <translation>Mobile Fußgängerkarte bei Nacht</translation>
    </message>
    <message>
        <source>Mobile pedestrian map view in night mode for mobile usage</source>
        <translation>Fußgängerkarte für mobilen Einsatz bei Nacht</translation>
    </message>
    <message>
        <source>Pedestrian Night Street Map</source>
        <translation>Fußgängerkarte bei Nacht</translation>
    </message>
    <message>
        <source>Car Navigation Map</source>
        <translation>Karte (Fahrzeugnavigation)</translation>
    </message>
    <message>
        <source>Normal map view in daylight mode for car navigation</source>
        <translation>Karte für Fahrzeugnavigation bei Tageslicht</translation>
    </message>
</context>
<context>
    <name>QGeoTiledMappingManagerEngineOsm</name>
    <message>
        <source>Street Map</source>
        <translation>Straßenkarte</translation>
    </message>
    <message>
        <source>Street map view in daylight mode</source>
        <translation>Ansicht Straßenkarte bei Tageslicht</translation>
    </message>
    <message>
        <source>Satellite map view in daylight mode</source>
        <translation>Ansicht Satellitenkarte bei Tageslicht</translation>
    </message>
    <message>
        <source>Cycle Map</source>
        <translation>Fahrradkarte</translation>
    </message>
    <message>
        <source>Cycle map view in daylight mode</source>
        <translation>Ansicht Fahrradkarte bei Tageslicht</translation>
    </message>
    <message>
        <source>Transit Map</source>
        <translation>Nahverkehrskarte</translation>
    </message>
    <message>
        <source>Public transit map view in daylight mode</source>
        <translation>Ansicht Nahverkehrskarte bei Tageslicht</translation>
    </message>
    <message>
        <source>Night Transit Map</source>
        <translation>Nahverkehrskarte bei Nacht</translation>
    </message>
    <message>
        <source>Public transit map view in night mode</source>
        <translation>Ansicht Nahverkehrskarte bei Nacht</translation>
    </message>
    <message>
        <source>Terrain Map</source>
        <translation>Topografische Karte</translation>
    </message>
    <message>
        <source>Terrain map view</source>
        <translation>Ansicht Topografische Karte</translation>
    </message>
    <message>
        <source>Hiking Map</source>
        <translation>Wanderkarte</translation>
    </message>
    <message>
        <source>Hiking map view</source>
        <translation>Ansicht Wanderkarte</translation>
    </message>
    <message>
        <source>Custom URL Map</source>
        <translation>Karte von benutzerdefinierter URL</translation>
    </message>
    <message>
        <source>Custom url map view set via urlprefix parameter</source>
        <translation>Ansicht Karte von benutzerdefinierter URL</translation>
    </message>
    <message>
        <source>Satellite Map</source>
        <translation>Satellitenkarte</translation>
    </message>
</context>
<context>
    <name>QPlaceManagerEngineOsm</name>
    <message>
        <source>Aeroway</source>
        <translation>Luftverkehr</translation>
    </message>
    <message>
        <source>Amenity</source>
        <translation>Öffentliche Einrichtung</translation>
    </message>
    <message>
        <source>Building</source>
        <translation>Gebäude</translation>
    </message>
    <message>
        <source>Highway</source>
        <translation>Straße</translation>
    </message>
    <message>
        <source>Historic</source>
        <translation>Historisch</translation>
    </message>
    <message>
        <source>Land use</source>
        <translation>Landnutzung</translation>
    </message>
    <message>
        <source>Leisure</source>
        <translation>Freizeit</translation>
    </message>
    <message>
        <source>Man made</source>
        <translation>Menschlichen Ursprungs</translation>
    </message>
    <message>
        <source>Natural</source>
        <translation>Natürlich</translation>
    </message>
    <message>
        <source>Place</source>
        <translation>Ort</translation>
    </message>
    <message>
        <source>Railway</source>
        <translation>Eisenbahn</translation>
    </message>
    <message>
        <source>Shop</source>
        <translation>Geschäft</translation>
    </message>
    <message>
        <source>Tourism</source>
        <translation>Tourismus</translation>
    </message>
    <message>
        <source>Waterway</source>
        <translation>Wasserweg</translation>
    </message>
    <message>
        <source>Network request error</source>
        <translation>Netzwerkfehler</translation>
    </message>
</context>
<context>
    <name>QPlaceSearchReplyMapbox</name>
    <message>
        <source>Response parse error</source>
        <translation>Fehler beim Auswerten der Antwort</translation>
    </message>
</context>
<context>
    <name>QPlaceSearchReplyOsm</name>
    <message>
        <source>Response parse error</source>
        <translation>Fehler beim Auswerten der Antwort</translation>
    </message>
</context>
<context>
    <name>QPlaceSearchSuggestionReplyMapbox</name>
    <message>
        <source>Response parse error</source>
        <translation>Fehler beim Auswerten der Antwort</translation>
    </message>
</context>
<context>
    <name>QtLocationQML</name>
    <message>
        <source>Qt Location requires apiKey parameter.
Please register at https://developer.here.com/ to get your personal application credentials.</source>
        <translation>Qt Location benötigt einen apiKey-Parameter.
Bitte registrieren Sie sich unter https://developer.here.com/ um Ihre persönlichen Anmeldedaten zu erhalten.</translation>
    </message>
    <message>
        <source>Saving places is not supported.</source>
        <translation>Speichern von Orten wird nicht unterstützt.</translation>
    </message>
    <message>
        <source>Removing places is not supported.</source>
        <translation>Löschen von Orten wird nicht unterstützt.</translation>
    </message>
    <message>
        <source>Saving categories is not supported.</source>
        <translation>Speichern von Kategorien wird nicht unterstützt.</translation>
    </message>
    <message>
        <source>Removing categories is not supported.</source>
        <translation>Löschen von Kategorien wird nicht unterstützt.</translation>
    </message>
    <message>
        <source>Error parsing response.</source>
        <translation>Fehler bim Parsen der Antwort.</translation>
    </message>
    <message>
        <source>Network error.</source>
        <translation>Netzwerkfehler.</translation>
    </message>
    <message>
        <source>Request was canceled.</source>
        <translation>Anfrage wurde abgebrochen.</translation>
    </message>
    <message>
        <source>The response from the service was not in a recognizable format.</source>
        <translation>Die Antwort des Dienstes war in keinem erkennbaren Format.</translation>
    </message>
    <message>
        <source>Plugin property is not set.</source>
        <translation>Plug-in Property wurde nicht gesetzt.</translation>
    </message>
    <message>
        <source>Plugin Error (%1): %2</source>
        <translation>Plug-in Fehler (%1): %2</translation>
    </message>
    <message>
        <source>Plugin Error (%1): Could not instantiate provider</source>
        <translation>Plug-in Fehler: Der %1 - Provider konnte nicht instanziiert werden</translation>
    </message>
    <message>
        <source>Plugin is not valid</source>
        <translation>Plug-in ist ungültig</translation>
    </message>
    <message>
        <source>Unable to initialize categories</source>
        <translation>Kategorien konnten nicht initialisiert werden</translation>
    </message>
    <message>
        <source>Unable to create request</source>
        <translation>Anfrage konnte nicht erstellt werden</translation>
    </message>
    <message>
        <source>Index &apos;%1&apos; out of range</source>
        <translation>Der Index &apos;%1&apos; ist außerhalb des gültigen Bereichs</translation>
    </message>
</context>
</TS>
